/// new | 9.10 New Experimental Feature
Blocks is currently a new, experimental extension type available in Pymdown Extensions that allows for writing a new
kind of block extension in Python Markdown. With this new addition, we've added a number of new extensions utilizing
this new extension type. While its intention is to hopefully replace extensions like Details and Tabbed, there are
currently no immediate plans to deprecate those plugins.

Any and all feedback regarding these new, experimental blocks is appreciated. Please provide feedback here:
https://github.com/facelessuser/pymdown-extensions/discussions/1973.
///
